@@ -1,13 +1,13 @@
 /*------------------------------------------------------------------------------
 
-   Copyright (c) 2000 Tyrell Corporation. All rights reserved.
+   Copyright (c) 2000-2007 Tyrell Corporation. All rights reserved.
 
    Tyrell DarkIce
 
    File     : AudioEncoder.h
-   Version  : $Revision: 1.9 $
-   Author   : $Author: jbebel $
-   Location : $Source: /cvsroot/darkice/darkice/src/AudioEncoder.h,v $
+   Version  : $Revision: 394 $
+   Author   : $Author: darkeye $
+   Location : $HeadURL$
    
    Copyright notice:
 
@@ -52,8 +52,8 @@
 /**
  *  An audio encoder
  *
- *  @author  $Author: jbebel $
- *  @version $Revision: 1.9 $
+ *  @author  $Author: darkeye $
+ *  @version $Revision: 394 $
  */
 class AudioEncoder : public Sink, public virtual Referable
 {
@@ -71,6 +71,11 @@ class AudioEncoder : public Sink, public virtual Referable
 
     private:
 
+        /**
+         *  The Sink to dump the encoded data to
+         */
+        Ref<Sink>           sink;
+
         /**
          *  Sample rate of the input.
          */
@@ -119,6 +124,7 @@ class AudioEncoder : public Sink, public virtual Referable
         /**
          *  Initialize the object.
          *
+         *  @param sink the sink to send encoded output to
          *  @param inSampleRate sample rate of the input.
          *  @param inBitsPerSample number of bits per sample of the input.
          *  @param inChannel number of channels  of the input.
@@ -130,7 +136,8 @@ class AudioEncoder : public Sink, public virtual Referable
          *  @exception Exception
          */
         inline void
-        init (      unsigned int    inSampleRate,
+        init (      Sink          * sink,
+                    unsigned int    inSampleRate,
                     unsigned int    inBitsPerSample,
                     unsigned int    inChannel,
                     bool            inBigEndian,
@@ -140,6 +147,7 @@ class AudioEncoder : public Sink, public virtual Referable
                     unsigned int    outSampleRate,
                     unsigned int    outChannel )        throw ( Exception )
         {
+            this->sink             = sink;
             this->inSampleRate     = inSampleRate;
             this->inBitsPerSample  = inBitsPerSample;
             this->inChannel        = inChannel;
@@ -182,6 +190,7 @@ class AudioEncoder : public Sink, public virtual Referable
         /**
          *  Constructor.
          *
+         *  @param sink the sink to send encoded output to
          *  @param inSampleRate sample rate of the input.
          *  @param inBitsPerSample number of bits per sample of the input.
          *  @param inChannel number of channels  of the input.
@@ -196,7 +205,8 @@ class AudioEncoder : public Sink, public virtual Referable
          *  @exception Exception
          */
         inline
-        AudioEncoder (  unsigned int    inSampleRate,
+        AudioEncoder (  Sink          * sink,
+                        unsigned int    inSampleRate,
                         unsigned int    inBitsPerSample,
                         unsigned int    inChannel, 
                         bool            inBigEndian,
@@ -207,7 +217,8 @@ class AudioEncoder : public Sink, public virtual Referable
                         unsigned int    outChannel    = 0 )
                                                         throw ( Exception )
         {
-            init ( inSampleRate,
+            init ( sink,
+                   inSampleRate,
                    inBitsPerSample,
                    inChannel,
                    inBigEndian,
@@ -221,6 +232,7 @@ class AudioEncoder : public Sink, public virtual Referable
         /**
          *  Constructor.
          *
+         *  @param sink the sink to send encoded output to
          *  @param as get input sample rate, bits per sample and channels
          *            from this AudioSource.
          *  @param outBitrateMode the bit rate mode of the output.
@@ -233,7 +245,8 @@ class AudioEncoder : public Sink, public virtual Referable
          *  @exception Exception
          */
         inline
-        AudioEncoder (  const AudioSource     * as,
+        AudioEncoder (  Sink                  * sink,
+                        const AudioSource     * as,
                         BitrateMode             outBitrateMode,
                         unsigned int            outBitrate,
                         double                  outQuality,
@@ -241,7 +254,8 @@ class AudioEncoder : public Sink, public virtual Referable
                         unsigned int            outChannel    = 0 )
                                                         throw ( Exception)
         {
-            init( as->getSampleRate(),
+            init( sink,
+                  as->getSampleRate(),
                   as->getBitsPerSample(),
                   as->getChannel(),
                   as->isBigEndian(),
@@ -260,7 +274,8 @@ class AudioEncoder : public Sink, public virtual Referable
         inline
         AudioEncoder (  const AudioEncoder &    encoder )   throw ( Exception )
         {
-            init ( encoder.inSampleRate,
+            init ( encoder.sink.get(),
+                   encoder.inSampleRate,
                    encoder.inBitsPerSample,
                    encoder.inChannel,
                    encoder.inBigEndian,
@@ -284,7 +299,8 @@ class AudioEncoder : public Sink, public virtual Referable
             if ( this != &encoder ) {
                 strip();
 
-                init ( encoder.inSampleRate,
+                init ( encoder.sink.get(),
+                       encoder.inSampleRate,
                        encoder.inBitsPerSample,
                        encoder.inChannel,
                        encoder.inBigEndian,
@@ -312,6 +328,17 @@ class AudioEncoder : public Sink, public virtual Referable
             strip();
         }
 
+        /**
+         *  Get the underlying sink, that the encoded content is sent to.
+         *
+         *  @return the underlying sink
+         */
+        inline virtual Ref<Sink>
+        getSink(void)                   throw ()
+        {
+            return sink;
+        }
+
         /**
          *  Get the number of channels of the input.
          *
@@ -438,6 +465,20 @@ class AudioEncoder : public Sink, public virtual Referable
          */
         virtual void
         stop ( void )                       throw ( Exception )     = 0;
+
+        /**
+         *  Cut what the sink has been doing so far, and start anew.
+         *  This usually means separating the data sent to the sink up
+         *  until now, and start saving a new chunk of data.
+         *
+         *  Typically this action is delegated to the underlying sink.
+         */
+        inline virtual void
+        cut ( void )                                    throw ()
+        {
+            sink->cut();
+        }
+
 };
 
 
@@ -450,39 +491,3 @@ class AudioEncoder : public Sink, public virtual Referable
 
 #endif  /* AUDIO_ENCODER_H */
 
-
-/*------------------------------------------------------------------------------
- 
-  $Source: /cvsroot/darkice/darkice/src/AudioEncoder.h,v $
-
-  $Log: AudioEncoder.h,v $
-  Revision 1.9  2005/04/13 18:03:43  jbebel
-  Allow quality settings down to -0.1 for ogg
-
-  Revision 1.8  2002/08/20 19:35:37  darkeye
-  added possibility to specify maximum bitrate for Ogg Vorbis streams
-
-  Revision 1.7  2002/04/13 11:26:00  darkeye
-  added cbr, abr and vbr setting feature with encoding quality
-
-  Revision 1.6  2002/03/28 16:39:32  darkeye
-  added interface for variable bitrate encoding
-
-  Revision 1.5  2002/02/19 15:23:59  darkeye
-  fixed typo
-
-  Revision 1.4  2001/09/18 14:57:19  darkeye
-  finalized Solaris port
-
-  Revision 1.3  2001/09/14 19:31:06  darkeye
-  added IceCast2 / vorbis support
-
-  Revision 1.2  2000/11/12 14:54:50  darkeye
-  added kdoc-style documentation comments
-
-  Revision 1.1.1.1  2000/11/05 10:05:47  darkeye
-  initial version
-
-  
-------------------------------------------------------------------------------*/
-
