@@ -5,7 +5,7 @@
    Tyrell DarkIce
 
    File     : AudioSource.cpp
-   Version  : $Revision: 400 $
+   Version  : $Revision: 424 $
    Author   : $Author: darkeye $
    Location : $HeadURL$
    
@@ -46,7 +46,7 @@
 /*------------------------------------------------------------------------------
  *  File identity
  *----------------------------------------------------------------------------*/
-static const char fileid[] = "$Id: AudioSource.cpp 400 2007-02-25 17:04:17Z darkeye $";
+static const char fileid[] = "$Id: AudioSource.cpp 424 2008-07-07 14:33:34Z darkeye $";
 
 
 /* ===============================================  local function prototypes */
@@ -60,6 +60,7 @@ static const char fileid[] = "$Id: AudioSource.cpp 400 2007-02-25 17:04:17Z dark
  *----------------------------------------------------------------------------*/
 AudioSource *
 AudioSource :: createDspSource( const char    * deviceName,
+                                const char    * jackClientName,
                                 int             sampleRate,
                                 int             bitsPerSample,
                                 int             channel)
@@ -101,6 +102,7 @@ AudioSource :: createDspSource( const char    * deviceName,
 #if defined( SUPPORT_JACK_DSP )
         Reporter::reportEvent( 1, "Using JACK audio server as input device.");
         return new JackDspSource( deviceName,
+                                  jackClientName,
                                   sampleRate,
                                   bitsPerSample,
                                   channel);
