@@ -1,13 +1,13 @@
 /*------------------------------------------------------------------------------
 
-   Copyright (c) 2000 Tyrell Corporation. All rights reserved.
+   Copyright (c) 2000-2007 Tyrell Corporation. All rights reserved.
 
    Tyrell DarkIce
 
    File     : BufferedSink.h
-   Version  : $Revision: 1.8 $
-   Author   : $Author: jbebel $
-   Location : $Source: /cvsroot/darkice/darkice/src/BufferedSink.h,v $
+   Version  : $Revision: 394 $
+   Author   : $Author: darkeye $
+   Location : $HeadURL$
    
    Copyright notice:
 
@@ -55,8 +55,8 @@
  *  data contained if needed.
  *  The class is not thread-safe.
  *
- *  @author  $Author: jbebel $
- *  @version $Revision: 1.8 $
+ *  @author  $Author: darkeye $
+ *  @version $Revision: 394 $
  */
 class BufferedSink : public Sink, public virtual Reporter
 {
@@ -366,6 +366,18 @@ class BufferedSink : public Sink, public virtual Reporter
             write( b, 0);
         }
 
+        /**
+         *  Cut what the sink has been doing so far, and start anew.
+         *  This usually means separating the data sent to the sink up
+         *  until now, and start saving a new chunk of data.
+         */
+        inline virtual void
+        cut ( void )                                    throw ()
+        {
+            flush();
+            sink->cut();
+        }
+
         /**
          *  Close the BufferedSink. Closes the underlying Sink.
          *
@@ -385,37 +397,3 @@ class BufferedSink : public Sink, public virtual Reporter
 
 #endif  /* BUFFERED_SINK_H */
 
-
-/*------------------------------------------------------------------------------
- 
-  $Source: /cvsroot/darkice/darkice/src/BufferedSink.h,v $
-
-  $Log: BufferedSink.h,v $
-  Revision 1.8  2005/04/03 05:01:46  jbebel
-  Fix peak reporting to report new peak rather than previous
-
-  Revision 1.7  2002/07/21 08:47:06  darkeye
-  some exception cleanup (throw clauses in function declarations)
-
-  Revision 1.6  2002/05/28 12:35:41  darkeye
-  code cleanup: compiles under gcc-c++ 3.1, using -pedantic option
-
-  Revision 1.5  2000/11/15 18:08:42  darkeye
-  added multiple verbosity-level event reporting and verbosity command
-  line option
-
-  Revision 1.4  2000/11/11 12:33:13  darkeye
-  added kdoc-style documentation
-
-  Revision 1.3  2000/11/10 20:16:21  darkeye
-  first real tests with multiple streaming
-
-  Revision 1.2  2000/11/05 17:37:24  darkeye
-  removed clone() functions
-
-  Revision 1.1.1.1  2000/11/05 10:05:48  darkeye
-  initial version
-
-  
-------------------------------------------------------------------------------*/
-
