@@ -1,13 +1,13 @@
 /*------------------------------------------------------------------------------
 
-   Copyright (c) 2000 Tyrell Corporation. All rights reserved.
+   Copyright (c) 2000-2007 Tyrell Corporation. All rights reserved.
 
    Tyrell DarkIce
 
    File     : Connector.h
-   Version  : $Revision: 1.6 $
+   Version  : $Revision: 394 $
    Author   : $Author: darkeye $
-   Location : $Source: /cvsroot/darkice/darkice/src/Connector.h,v $
+   Location : $HeadURL$
    
    Copyright notice:
 
@@ -55,7 +55,7 @@
  *  Connects a source to one or more sinks.
  *
  *  @author  $Author: darkeye $
- *  @version $Revision: 1.6 $
+ *  @version $Revision: 394 $
  */
 class Connector : public virtual Referable, public virtual Reporter
 {
@@ -234,6 +234,15 @@ class Connector : public virtual Referable, public virtual Reporter
                     unsigned int        sec,
                     unsigned int        usec )          throw ( Exception );
 
+        /**
+         *  Signal to each sink we have that they need to cut what they are
+         *  doing, and start again. For FileSinks, this usually means to
+         *  save the archive file recorded so far, and start a new archive
+         *  file.
+         */
+        virtual void
+        cut ( void )                                throw ();
+
         /**
          *  Close the Connector. The Source and all Sinks are closed.
          *
@@ -253,34 +262,3 @@ class Connector : public virtual Referable, public virtual Reporter
 
 #endif  /* CONNECTOR_H */
 
-
-/*------------------------------------------------------------------------------
- 
-  $Source: /cvsroot/darkice/darkice/src/Connector.h,v $
-
-  $Log: Connector.h,v $
-  Revision 1.6  2002/10/19 12:24:55  darkeye
-  anged internals so that now each encoding/server connection is
-  a separate thread
-
-  Revision 1.5  2001/08/26 20:44:30  darkeye
-  removed external command-line encoder support
-  replaced it with a shared-object support for lame with the possibility
-  of static linkage
-
-  Revision 1.4  2000/11/15 18:37:37  darkeye
-  changed the transferable number of bytes to unsigned long
-
-  Revision 1.3  2000/11/15 18:08:43  darkeye
-  added multiple verbosity-level event reporting and verbosity command
-  line option
-
-  Revision 1.2  2000/11/13 18:46:50  darkeye
-  added kdoc-style documentation comments
-
-  Revision 1.1.1.1  2000/11/05 10:05:49  darkeye
-  initial version
-
-  
-------------------------------------------------------------------------------*/
-
