@@ -5,8 +5,8 @@
    Tyrell DarkIce
 
    File     : IceCast2.cpp
-   Version  : $Revision: 394 $
-   Author   : $Author: darkeye $
+   Version  : $Revision: 446 $
+   Author   : $Author: diniz@wimobilis.com.br $
    Location : $HeadURL$
    
    Copyright notice:
@@ -67,7 +67,7 @@
 /*------------------------------------------------------------------------------
  *  File identity
  *----------------------------------------------------------------------------*/
-static const char fileid[] = "$Id: IceCast2.cpp 394 2007-01-14 16:28:42Z darkeye $";
+static const char fileid[] = "$Id: IceCast2.cpp 446 2009-06-21 04:36:30Z diniz@wimobilis.com.br $";
 
 
 /*------------------------------------------------------------------------------
@@ -161,6 +161,10 @@ IceCast2 :: sendLogin ( void )                           throw ( Exception )
             str = "audio/aac";
             break;
 
+        case aacp:
+            str = "audio/aacp";
+            break;
+
         default:
             throw Exception( __FILE__, __LINE__,
                              "unsupported stream format", format);
