@@ -5,8 +5,8 @@
    Tyrell DarkIce
 
    File     : IceCast2.h
-   Version  : $Revision: 394 $
-   Author   : $Author: darkeye $
+   Version  : $Revision: 446 $
+   Author   : $Author: diniz@wimobilis.com.br $
    Location : $HeadURL$
    
    Copyright notice:
@@ -53,8 +53,8 @@
  *  Class representing output to an IceCast2 server with
  *  ice login
  *
- *  @author  $Author: darkeye $
- *  @version $Revision: 394 $
+ *  @author  $Author: diniz@wimobilis.com.br $
+ *  @version $Revision: 446 $
  */
 class IceCast2 : public CastSink
 {
@@ -63,7 +63,7 @@ class IceCast2 : public CastSink
         /**
          *  Type for specifying the format of the stream.
          */
-       enum StreamFormat { mp3, mp2, oggVorbis, aac };
+       enum StreamFormat { mp3, mp2, oggVorbis, aac, aacp };
 
 
     private:
