@@ -7,8 +7,8 @@
    Tyrell DarkIce
 
    File     : JackDspSource.cpp
-   Version  : $Revision: 429 $
-   Author   : $Author: darkeye $
+   Version  : $Revision: 447 $
+   Author   : $Author: rafael@riseup.net $
    Location : $HeadURL$
    
    Copyright notice:
@@ -64,6 +64,18 @@
 #error need math.h
 #endif
 
+#ifdef HAVE_STDLIB_H
+#include <stdlib.h>
+#else
+#error needs stdlib.h
+#endif
+
+#ifdef HAVE_LIMITS_H
+#include <limits.h>
+#else
+#error need limits.h
+#endif
+
 #include "Util.h"
 #include "Exception.h"
 #include "JackDspSource.h"
@@ -77,7 +89,7 @@
 /*------------------------------------------------------------------------------
  *  File identity
  *----------------------------------------------------------------------------*/
-static const char fileid[] = "$Id: JackDspSource.cpp 429 2008-07-07 17:36:19Z darkeye $";
+static const char fileid[] = "$Id: JackDspSource.cpp 447 2009-11-05 17:47:44Z rafael@riseup.net $";
 
 
 /* ===============================================  local function prototypes */
