@@ -7,7 +7,7 @@
    Tyrell DarkIce
 
    File     : JackDspSource.h
-   Version  : $Revision: 394 $
+   Version  : $Revision: 424 $
    Author   : $Author: darkeye $
    Location : $HeadURL$
    
@@ -62,11 +62,15 @@
  *  An audio input based on JACK
  *
  *  @author  $Author: darkeye $
- *  @version $Revision: 394 $
+ *  @version $Revision: 424 $
  */
 class JackDspSource : public AudioSource, public virtual Reporter
 {
     private:
+        /**
+         *  The jack client name.
+         */
+        const char                   * jack_client_name;
 
         /**
          *  The jack port
@@ -156,6 +160,7 @@ class JackDspSource : public AudioSource, public virtual Reporter
          */
         inline
         JackDspSource ( const char    * name,
+                        const char    * jackClientName,
                         int             sampleRate    = 44100,
                         int             bitsPerSample = 16,
                         int             channels      = 2 )
@@ -163,6 +168,7 @@ class JackDspSource : public AudioSource, public virtual Reporter
 
                     : AudioSource( sampleRate, bitsPerSample, channels )
         {
+            jack_client_name = jackClientName;
             init( name );
         }
 
