@@ -1,13 +1,13 @@
 /*------------------------------------------------------------------------------
 
-   Copyright (c) 2000 Tyrell Corporation. All rights reserved.
+   Copyright (c) 2000-2007 Tyrell Corporation. All rights reserved.
 
    Tyrell DarkIce
 
    File     : LameLibEncoder.h
-   Version  : $Revision: 1.16 $
+   Version  : $Revision: 394 $
    Author   : $Author: darkeye $
-   Location : $Source: /cvsroot/darkice/darkice/src/LameLibEncoder.h,v $
+   Location : $HeadURL$
    
    Copyright notice:
 
@@ -67,7 +67,7 @@
  *  a static library.
  *
  *  @author  $Author: darkeye $
- *  @version $Revision: 1.16 $
+ *  @version $Revision: 394 $
  */
 class LameLibEncoder : public AudioEncoder, public virtual Reporter
 {
@@ -78,11 +78,6 @@ class LameLibEncoder : public AudioEncoder, public virtual Reporter
          */
         lame_global_flags             * lameGlobalFlags;
 
-        /**
-         *  The Sink to dump mp3 data to
-         */
-        Ref<Sink>                       sink;
-
         /**
          *  Lowpass filter. Sound frequency in Hz, from where up the
          *  input is cut.
@@ -98,7 +93,6 @@ class LameLibEncoder : public AudioEncoder, public virtual Reporter
         /**
          *  Initialize the object.
          *
-         *  @param sink the sink to send mp3 output to
          *  @param lowpass frequency threshold for the lowpass filter.
          *                 Input above this frequency is cut.
          *                 If 0, lame's default values are used,
@@ -110,12 +104,10 @@ class LameLibEncoder : public AudioEncoder, public virtual Reporter
          *  @exception Exception
          */
         inline void
-        init ( Sink           * sink,
-               int              lowpass,
+        init ( int              lowpass,
                int              highpass )              throw ( Exception )
         {
             this->lameGlobalFlags = NULL;
-            this->sink            = sink;
             this->lowpass         = lowpass;
             this->highpass        = highpass;
 
@@ -209,7 +201,8 @@ class LameLibEncoder : public AudioEncoder, public virtual Reporter
                             int             highpass      = 0 )
                                                         throw ( Exception )
             
-                    : AudioEncoder ( inSampleRate,
+                    : AudioEncoder ( sink,
+                                     inSampleRate,
                                      inBitsPerSample,
                                      inChannel,
                                      inBigEndian,
@@ -219,7 +212,7 @@ class LameLibEncoder : public AudioEncoder, public virtual Reporter
                                      outSampleRate,
                                      outChannel )
         {
-            init( sink, lowpass, highpass);
+            init( lowpass, highpass);
         }
 
         /**
@@ -257,14 +250,15 @@ class LameLibEncoder : public AudioEncoder, public virtual Reporter
                             int                     highpass      = 0 )
                                                             throw ( Exception )
             
-                    : AudioEncoder ( as,
+                    : AudioEncoder ( sink,
+                                     as,
                                      outBitrateMode,
                                      outBitrate,
                                      outQuality,
                                      outSampleRate,
                                      outChannel )
         {
-            init( sink, lowpass, highpass);
+            init( lowpass, highpass);
         }
 
         /**
@@ -277,7 +271,7 @@ class LameLibEncoder : public AudioEncoder, public virtual Reporter
                                                             throw ( Exception )
                     : AudioEncoder( encoder )
         {
-            init( encoder.sink.get(), encoder.lowpass, encoder.highpass );
+            init( encoder.lowpass, encoder.highpass );
         }
          
 
@@ -308,7 +302,7 @@ class LameLibEncoder : public AudioEncoder, public virtual Reporter
             if ( this != &encoder ) {
                 strip();
                 AudioEncoder::operator=( encoder);
-                init( encoder.sink.get(), encoder.lowpass, encoder.highpass );
+                init( encoder.lowpass, encoder.highpass );
             }
 
             return *this;
@@ -442,64 +436,3 @@ class LameLibEncoder : public AudioEncoder, public virtual Reporter
 
 #endif  /* LAME_LIB_ENCODER_H */
 
-
-/*------------------------------------------------------------------------------
- 
-  $Source: /cvsroot/darkice/darkice/src/LameLibEncoder.h,v $
-
-  $Log: LameLibEncoder.h,v $
-  Revision 1.16  2005/04/16 21:57:34  darkeye
-  added AAC support through the faac codec, http://www.audiocoding.com/
-
-  Revision 1.15  2004/01/07 13:18:17  darkeye
-  commited patch sent by John Hay, fixing FreeBSD problems
-
-  Revision 1.14  2002/08/04 10:26:06  darkeye
-  added additional error checking to make sure that outChannel < inChannel
-
-  Revision 1.13  2002/08/03 12:41:18  darkeye
-  added possibility to stream in mono when recording in stereo
-
-  Revision 1.12  2002/04/13 11:26:00  darkeye
-  added cbr, abr and vbr setting feature with encoding quality
-
-  Revision 1.11  2002/03/28 16:38:37  darkeye
-  moved functions conv8() and conv16() to class Util
-
-  Revision 1.10  2001/10/20 10:56:45  darkeye
-  added possibility to disable highpass and lowpass filters for lame
-
-  Revision 1.9  2001/10/19 12:39:42  darkeye
-  created configure options to compile with or without lame / Ogg Vorbis
-
-  Revision 1.8  2001/10/19 09:03:39  darkeye
-  added support for resampling mp3 streams
-
-  Revision 1.7  2001/09/15 11:35:08  darkeye
-  minor fixes
-
-  Revision 1.6  2001/09/14 19:31:06  darkeye
-  added IceCast2 / vorbis support
-
-  Revision 1.5  2001/09/02 09:54:12  darkeye
-  fixed typos in CVS substition keywords
-
-  Revision 1.4  2001/08/31 20:09:05  darkeye
-  added funcitons conv8() and conv16()
-
-  Revision 1.3  2001/08/30 17:25:56  darkeye
-  renamed configure.h to config.h
-
-  Revision 1.2  2001/08/29 21:06:16  darkeye
-  added real support for 8 / 16 bit mono / stereo input
-  (8 bit input still has to be spread on 16 bit words)
-
-  Revision 1.1  2001/08/26 20:44:30  darkeye
-  removed external command-line encoder support
-  replaced it with a shared-object support for lame with the possibility
-  of static linkage
-
-
-  
-------------------------------------------------------------------------------*/
-
