@@ -5,8 +5,8 @@
    Tyrell DarkIce
 
    File     : TcpSocket.cpp
-   Version  : $Revision: 399 $
-   Author   : $Author: darkeye $
+   Version  : $Revision: 446 $
+   Author   : $Author: diniz@wimobilis.com.br $
    Location : $HeadURL$
    
    Copyright notice:
@@ -101,7 +101,7 @@
 /*------------------------------------------------------------------------------
  *  File identity
  *----------------------------------------------------------------------------*/
-static const char fileid[] = "$Id: TcpSocket.cpp 399 2007-02-25 16:38:33Z darkeye $";
+static const char fileid[] = "$Id: TcpSocket.cpp 446 2009-06-21 04:36:30Z diniz@wimobilis.com.br $";
 
 
 /* ===============================================  local function prototypes */
@@ -215,12 +215,14 @@ TcpSocket :: open ( void )                       throw ( Exception )
     snprintf(portstr, sizeof(portstr), "%d", port);
 
     if (getaddrinfo(host , portstr, &hints, &ptr)) {
+        sockfd = 0;
         throw Exception( __FILE__, __LINE__, "getaddrinfo error", errno);
     }
     memcpy ( addr, ptr->ai_addr, ptr->ai_addrlen);
     freeaddrinfo(ptr);
 #else
     if ( !(pHostEntry = gethostbyname( host)) ) {
+        sockfd = 0;
         throw Exception( __FILE__, __LINE__, "gethostbyname error", errno);
     }
     
@@ -231,6 +233,7 @@ TcpSocket :: open ( void )                       throw ( Exception )
 #endif
 
     if ( (sockfd = socket( AF_INET, SOCK_STREAM,  IPPROTO_TCP)) == -1 ) {
+        sockfd = 0;
         throw Exception( __FILE__, __LINE__, "socket error", errno);
     }
 
@@ -281,6 +284,8 @@ TcpSocket :: canRead (      unsigned int    sec,
     ret = pselect( sockfd + 1, &fdset, NULL, NULL, &timespec, &sigset);
 
     if ( ret == -1 ) {
+        ::close( sockfd);
+        sockfd = 0;
         throw Exception( __FILE__, __LINE__, "select error");
     }
 
@@ -313,7 +318,9 @@ TcpSocket :: read (     void          * buf,
                 break;
 
             default:
-                throw Exception( __FILE__, __LINE__, "recv error", errno);
+		::close( sockfd);
+		sockfd = 0;
+		throw Exception( __FILE__, __LINE__, "recv error", errno);
         }
     }
 
@@ -350,6 +357,8 @@ TcpSocket :: canWrite (    unsigned int    sec,
     ret = pselect( sockfd + 1, NULL, &fdset, NULL, &timespec, &sigset);
     
     if ( ret == -1 ) {
+	::close( sockfd);
+	sockfd = 0;
         throw Exception( __FILE__, __LINE__, "select error");
     }
 
@@ -380,6 +389,8 @@ TcpSocket :: write (    const void    * buf,
         if ( errno == EAGAIN ) {
             ret = 0;
         } else {
+	    ::close( sockfd);
+	    sockfd = 0;
             throw Exception( __FILE__, __LINE__, "send error", errno);
         }
     }
