@@ -5,8 +5,8 @@
    Tyrell DarkIce
 
    File     : Util.cpp
-   Version  : $Revision: 399 $
-   Author   : $Author: darkeye $
+   Version  : $Revision: 459 $
+   Author   : $Author: rafael@riseup.net $
    Location : $HeadURL$
    
    Copyright notice:
@@ -93,7 +93,7 @@
 /*------------------------------------------------------------------------------
  *  File identity
  *----------------------------------------------------------------------------*/
-static const char fileid[] = "$Id: Util.cpp 399 2007-02-25 16:38:33Z darkeye $";
+static const char fileid[] = "$Id: Util.cpp 459 2009-11-14 22:22:03Z rafael@riseup.net $";
 
 
 /* ===============================================  local function prototypes */
@@ -294,9 +294,9 @@ Util :: fileAddDate ( const char * str,
                       const char * format )             throw ( Exception )
 {
     unsigned int    size;
+    const char          * last; 
     char          * s;
     char          * strdate;
-    char          * last;
     time_t          now;
 
     if ( !str ) {
