@@ -1,13 +1,13 @@
 /*------------------------------------------------------------------------------
 
-   Copyright (c) 2000 Tyrell Corporation. All rights reserved.
+   Copyright (c) 2000-2007 Tyrell Corporation. All rights reserved.
 
    Tyrell DarkIce
 
    File     : VorbisLibEncoder.h
-   Version  : $Revision: 1.9 $
+   Version  : $Revision: 394 $
    Author   : $Author: darkeye $
-   Location : $Source: /cvsroot/darkice/darkice/src/VorbisLibEncoder.h,v $
+   Location : $HeadURL$
    
    Copyright notice:
 
@@ -68,7 +68,7 @@
  *  as a static library.
  *
  *  @author  $Author: darkeye $
- *  @version $Revision: 1.9 $
+ *  @version $Revision: 394 $
  */
 class VorbisLibEncoder : public AudioEncoder, public virtual Reporter
 {
@@ -104,11 +104,6 @@ class VorbisLibEncoder : public AudioEncoder, public virtual Reporter
          */
         ogg_stream_state                oggStreamState;
 
-        /**
-         *  The Sink to dump encoded data to
-         */
-        Ref<CastSink>                   sink;
-
         /**
          *  Maximum bitrate of the output in kbits/sec. If 0, don't care.
          */
@@ -127,13 +122,11 @@ class VorbisLibEncoder : public AudioEncoder, public virtual Reporter
         /**
          *  Initialize the object.
          *
-         *  @param sink the sink to send encoded output to
          *  @param the maximum bit rate
          *  @exception Exception
          */
         void
-        init ( CastSink       * sink,
-               unsigned int     outMaxBitrate )         throw ( Exception );
+        init ( unsigned int     outMaxBitrate )         throw ( Exception );
 
         /**
          *  De-initialize the object.
@@ -204,7 +197,8 @@ class VorbisLibEncoder : public AudioEncoder, public virtual Reporter
                             unsigned int    outMaxBitrate = 0 )
                                                         throw ( Exception )
             
-                    : AudioEncoder ( inSampleRate,
+                    : AudioEncoder ( sink,
+                                     inSampleRate,
                                      inBitsPerSample,
                                      inChannel, 
                                      inBigEndian,
@@ -214,7 +208,7 @@ class VorbisLibEncoder : public AudioEncoder, public virtual Reporter
                                      outSampleRate,
                                      outChannel )
         {
-            init( sink, outMaxBitrate);
+            init( outMaxBitrate);
         }
 
         /**
@@ -245,14 +239,15 @@ class VorbisLibEncoder : public AudioEncoder, public virtual Reporter
                             unsigned int            outMaxBitrate = 0 )
                                                             throw ( Exception )
             
-                    : AudioEncoder ( as,
+                    : AudioEncoder ( sink,
+                                     as,
                                      outBitrateMode,
                                      outBitrate,
                                      outQuality,
                                      outSampleRate,
                                      outChannel )
         {
-            init( sink, outMaxBitrate);
+            init( outMaxBitrate);
         }
 
         /**
@@ -268,7 +263,7 @@ class VorbisLibEncoder : public AudioEncoder, public virtual Reporter
             if( encoder.isOpen() ) {
                 throw Exception(__FILE__, __LINE__, "don't copy open encoders");
             }
-            init( encoder.sink.get(), encoder.getOutMaxBitrate() );
+            init( encoder.getOutMaxBitrate() );
         }
 
         /**
@@ -302,7 +297,7 @@ class VorbisLibEncoder : public AudioEncoder, public virtual Reporter
             if ( this != &encoder ) {
                 strip();
                 AudioEncoder::operator=( encoder);
-                init( encoder.sink.get(), encoder.getOutMaxBitrate() );
+                init( encoder.getOutMaxBitrate() );
             }
 
             return *this;
@@ -438,42 +433,3 @@ class VorbisLibEncoder : public AudioEncoder, public virtual Reporter
 
 #endif  /* VORBIS_LIB_ENCODER_H */
 
-
-/*------------------------------------------------------------------------------
- 
-  $Source: /cvsroot/darkice/darkice/src/VorbisLibEncoder.h,v $
-
-  $Log: VorbisLibEncoder.h,v $
-  Revision 1.9  2003/02/09 13:15:57  darkeye
-  added feature for setting the TITLE comment field for vorbis streams
-
-  Revision 1.8  2002/08/20 20:07:36  darkeye
-  minor fixes
-
-  Revision 1.7  2002/08/20 19:35:37  darkeye
-  added possibility to specify maximum bitrate for Ogg Vorbis streams
-
-  Revision 1.6  2002/07/20 16:37:06  darkeye
-  added fault tolerance in case a server connection is dropped
-
-  Revision 1.5  2002/04/13 11:26:00  darkeye
-  added cbr, abr and vbr setting feature with encoding quality
-
-  Revision 1.4  2002/03/28 16:47:38  darkeye
-  moved functions conv8() and conv16() to class Util (as conv())
-  added resampling functionality
-  added support for variable bitrates
-
-  Revision 1.3  2001/10/19 12:39:42  darkeye
-  created configure options to compile with or without lame / Ogg Vorbis
-
-  Revision 1.2  2001/09/15 11:36:22  darkeye
-  added function vorbisBlocksOut(), finalized vorbis support
-
-  Revision 1.1  2001/09/14 19:31:06  darkeye
-  added IceCast2 / vorbis support
-
-
-
-------------------------------------------------------------------------------*/
-
