@@ -1,13 +1,13 @@
 /*------------------------------------------------------------------------------
 
-   Copyright (c) 2000 Tyrell Corporation. All rights reserved.
+   Copyright (c) 2000-2007 Tyrell Corporation. All rights reserved.
 
    Tyrell DarkIce
 
    File     : main.cpp
-   Version  : $Revision: 1.16 $
+   Version  : $Revision: 394 $
    Author   : $Author: darkeye $
-   Location : $Source: /cvsroot/darkice/darkice/src/main.cpp,v $
+   Location : $HeadURL$
    
    Abstract : 
 
@@ -43,6 +43,12 @@
 #error needs stdlib.h
 #endif
 
+#ifdef HAVE_SIGNAL_H
+#include <signal.h>
+#else
+#error needs signal.h
+#endif
+
 #include <iostream>
 #include <fstream>
 
@@ -54,13 +60,23 @@
 
 /* ===================================================  local data structures */
 
+/*------------------------------------------------------------------------------
+ *  The DarkIce object we're running
+ *----------------------------------------------------------------------------*/
+static Ref<DarkIce>     darkice;
+
 
 /* ================================================  local constants & macros */
 
 /*------------------------------------------------------------------------------
  *  File identity
  *----------------------------------------------------------------------------*/
-static const char fileid[] = "$Id: main.cpp,v 1.16 2006/01/25 22:47:15 darkeye Exp $";
+static const char fileid[] = "$Id: main.cpp 394 2007-01-14 16:28:42Z darkeye $";
+
+/*------------------------------------------------------------------------------
+ *  Default config file name
+ *----------------------------------------------------------------------------*/
+static const char *DEFAULT_CONFIG_FILE = "/etc/darkice.cfg";
 
 
 /* ===============================================  local function prototypes */
@@ -71,6 +87,12 @@ static const char fileid[] = "$Id: main.cpp,v 1.16 2006/01/25 22:47:15 darkeye E
 static void
 showUsage (     std::ostream  & os );
 
+/*------------------------------------------------------------------------------
+ *  Handler for the SIGUSR1 signal
+ *----------------------------------------------------------------------------*/
+static void
+sigusr1Handler(int  value);
+
 
 /* =============================================================  module code */
 
@@ -85,13 +107,13 @@ main (
     int     res = -1;
 
     std::cout << "DarkIce " << VERSION
-         << " live audio streamer, http://darkice.sourceforge.net"
+         << " live audio streamer, http://darkice.tyrell.hu/"
          << std::endl
-         << "Copyright (c) 2000-2006, Tyrell Hungary, http://tyrell.hu"
+         << "Copyright (c) 2000-2007, Tyrell Hungary, http://tyrell.hu/"
          << std::endl << std::endl;
 
     try {
-        const char    * configFileName = 0;
+        const char    * configFileName = DEFAULT_CONFIG_FILE;
         unsigned int    verbosity      = 1;
         int             i;
         const char      opts[] = "hc:v:";
@@ -115,21 +137,18 @@ main (
             }
         }
 
-        if ( !configFileName ) {
-            showUsage( std::cout);
-            throw Exception( __FILE__, __LINE__,
-                             "no configuration file specified");
-        }
-
         std::cout << "Using config file: " << configFileName << std::endl;
 
         std::ifstream       configFile( configFileName);
         Reporter::setReportVerbosity( verbosity );
         Reporter::setReportOutputStream( std::cout );
         Config              config( configFile);
-        Ref<DarkIce>        di = new DarkIce( config);
 
-        res = di->run();
+        darkice = new DarkIce( config);
+
+        signal(SIGUSR1, sigusr1Handler);
+
+        res = darkice->run();
 
     } catch ( Exception   & e ) {
         std::cout << "DarkIce: " << e << std::endl << std::flush;
@@ -153,6 +172,8 @@ showUsage (     std::ostream      & os )
     << std::endl
     << "   -c config.file     use configuration file config.file"
     << std::endl
+    << "                      if not specified, /etc/darkice.cfg is used"
+    << std::endl
     << "   -v n               verbosity level (0 = silent, 10 = loud)"
     << std::endl
     << "   -h                 print this message and exit"
@@ -162,66 +183,11 @@ showUsage (     std::ostream      & os )
 
 
 /*------------------------------------------------------------------------------
- 
-  $Source: /cvsroot/darkice/darkice/src/main.cpp,v $
-
-  $Log: main.cpp,v $
-  Revision 1.16  2006/01/25 22:47:15  darkeye
-  added mpeg2 support, thanks to Nicholas J Humfrey
-
-  Revision 1.15  2005/04/14 11:24:42  darkeye
-  updated copyright notice to extend to 2005
-
-  Revision 1.14  2005/04/03 05:10:07  jbebel
-  Moved initialization of Reporter class so it would happen before
-  instantiation of Darkice class.  Any logging that might be reported
-  during the construction of the Darkice class could not function.
-  Originally the Reporter initialization was done through the instance
-  of Darkice (which inherits Reporter), but that obviously isn't possible
-  before Darkice is instantiated.  Since Reporter is largely a static class,
-  it is reasonable to call it via the scope resolution operator rather
-  than via an instance of the class, so that's what I did.
-
-  Revision 1.13  2004/02/15 12:06:30  darkeye
-  added ALSA support, thanks to Christian Forster
-
-  Revision 1.12  2003/02/09 15:09:41  darkeye
-  for version 0.13
-
-  Revision 1.11  2002/05/28 12:35:41  darkeye
-  code cleanup: compiles under gcc-c++ 3.1, using -pedantic option
-
-  Revision 1.10  2002/02/20 15:08:52  darkeye
-  minor changes
-
-  Revision 1.9  2001/09/11 15:05:21  darkeye
-  added Solaris support
-
-  Revision 1.8  2001/09/02 12:24:29  darkeye
-  now displays usage info when no command line parameters given
-
-  Revision 1.7  2001/08/30 17:25:56  darkeye
-  renamed configure.h to config.h
-
-  Revision 1.6  2001/08/26 08:43:13  darkeye
-  added support for unlimited time encoding
-
-  Revision 1.5  2000/11/15 18:08:43  darkeye
-  added multiple verbosity-level event reporting and verbosity command
-  line option
-
-  Revision 1.4  2000/11/13 20:21:29  darkeye
-  added program version display on startup
-
-  Revision 1.3  2000/11/13 19:38:55  darkeye
-  moved command line parameter parsing from DarkIce.cpp to main.cpp
-
-  Revision 1.2  2000/11/08 17:29:50  darkeye
-  added configuration file reader
-
-  Revision 1.1.1.1  2000/11/05 10:05:52  darkeye
-  initial version
-
-  
-------------------------------------------------------------------------------*/
+ *  Handle the SIGUSR1 signal here
+ *----------------------------------------------------------------------------*/
+static void
+sigusr1Handler(int    value)
+{
+    darkice->cut();
+}
 
